@@ -109,7 +109,7 @@ def indent(l):
     return l[:len(l) - len(l.lstrip())]
 
 
-def full_strip(lines, tags=None):
+def full_strip(lines : list, tags=("#!s", "#!o", "#!f", "#!b")):
     if tags is None:
         tags = ["#!s", "#!o", "#!f", "#!b"]
     for t in tags:
@@ -121,7 +121,7 @@ def strip_tag(lines, tag):
     lines2 = []
     for l in lines:
         dx = l.find(tag)
-        if dx > 0:
+        if dx >= 0:
             l = l[:dx]
             if len(l.strip()) == 0:
                 l = None
