@@ -66,7 +66,7 @@ def fix_f(lines, debug, keep=False):
     return lines2
 
 # stats = {'n': 0}
-def _block_fun(lines, start_extra, end_extra, keep=False, permute=False, questionmarks=False, halfquestionmarks=False, silent=False, nolines=False):
+def _block_fun(lines, start_extra, end_extra, keep=False, permute=False, questionmarks=False, halfquestionmarks=False, silent=False, nolines=False, noerror=False):
     methods = {'remove': 0}
     # if method not in ['remove', 'permute', 'questionmark', 'halfquestionmark']:
     #     assert False
@@ -80,7 +80,10 @@ def _block_fun(lines, start_extra, end_extra, keep=False, permute=False, questio
     if len(ee) >= 2 and ee[0] == '"':
         ee = ee[1:-1]
     if len(ee) == 0:
-        ee = "Insert your solution and remove this error."
+        if not permute:
+            ee = "Insert your solution and remove this error."
+        else:
+            ee = "Remove this exception after the above lines have been uncommented and rearranged."
     start_extra = start_extra.strip()
     if keep:
         l2 = ['GARBAGE'] * cc
@@ -93,15 +96,21 @@ def _block_fun(lines, start_extra, end_extra, keep=False, permute=False, questio
             insert_lines = False
             msg = []
             if permute:
-                msg = [id + "# TODO: The following lines have been permuted. Can you put them back in order?"]
+                sperm = f"# TODO: Oy veh, the following {cc} lines below have been permuted. Uncomment, rearrange to the correct order and remove the error."
+                msg = [id + f"#"+sperm, id + "#"+"-"*len(sperm)]
                 # Permute all lines.
                 lines = f1(lines)
                 insert_lines = True
                 pass
             if questionmarks:
+                sperm = f"# TODO: The following {cc} lines have been obfuscated by having characters replaced by questionmarks. Make it work and remove the error."
+                msg = [id + f"#" + sperm, id + "#" + "-" * len(sperm)]
                 lines = f2(lines)
                 insert_lines = True
             elif halfquestionmarks:
+                sperm = f"# TODO: Half of each line of code in the following {cc} lines have been replaced by garbage. Make it work and remove the error."
+                msg = [id + f"#" + sperm, id + "#" + "-" * len(sperm)]
+
                 lines = f3(lines)
                 insert_lines = True
             if not insert_lines:
@@ -113,7 +122,8 @@ def _block_fun(lines, start_extra, end_extra, keep=False, permute=False, questio
                 lines = [id + todo]
             else:
                 lines = msg + lines
-            lines += [id + f'raise NotImplementedError("{ee}")']
+            if not noerror:
+                lines += [id + f'raise NotImplementedError("{ee}")']
             l2 = ([id + start_extra] if len(start_extra) > 0 else []) + lines # [id + f"# TODO: {cc} lines missing.",
             # id + f'raise NotImplementedError("{ee}")']
     return l2, cc
