@@ -69,7 +69,8 @@ def fix_bibtex(lines, bibtex, rst_mode=False):
             s = f"{COMMENT}\n{COMMENT}\n" + s
         i = s.find(COMMENT, s.find(COMMENT)+1)
         all_refs = ["  " + r.strip() for r in all_refs]
-        s = s[:i] + "References:\n" + "\n".join(all_refs) +"\n"+ s[i:]
+        # Two newlines because of python styleguide.
+        s = s[:i].rstrip() + "\n\nReferences:\n" + "\n".join(all_refs) +"\n"+ s[i:]
 
     # s = s.replace(cpr, info['code_copyright'])
     return s.splitlines()
