@@ -73,19 +73,17 @@ def snip_dir(source_dir,  # Sources
             continue
 
         if accept and (str(f).endswith(".py") or str(f).endswith(".rst") or str(f).endswith(".md")):
-            # if f.endswith("rst"):
-            #     pass
             solution_list = []
             kwargs = {}
             if verbose:
                 print("Snipper processing", f)
             nrem, cut = censor_file(f, run_files=run_files, run_out_dirs=output_dir, cut_files=cut_files,
-                               # solution_list=solution_list,
                                base_path=dest_dir,
                                references=references,
                                license_head=license_head,
                                censor_files=censor_files,
-                                    package_base_dir=package_base_dir,
+                               package_base_dir=package_base_dir,
+                               verbose=verbose,
                                **kwargs)
             if nrem > 0 and verbose:
                 print(f"{nrem}> {f}")
