@@ -46,12 +46,14 @@ def censor_file(file, run_files=True, run_out_dirs=None, cut_files=True,
                 strict=True,
                 references=None,
                 license_head=None,
-                package_base_dir=None):
+                package_base_dir=None, verbose=False):
+
     if str(file).endswith("rst"):
         assert not run_files and not cut_files and not censor_files
-        # print(file)
-    # if str(file).endswith("md"):
-    #     assert not run_files and not cut_files
+
+    if str(file).endswith(".md"):
+        license_head=None
+
 
     if references == None:
         references = {}
@@ -86,7 +88,7 @@ def censor_file(file, run_files=True, run_out_dirs=None, cut_files=True,
             ofiles[0] = ofiles[0].replace("\\", "/")
 
             if run_files:
-                run_o(lines, file=file, output=ofiles[0], package_base_dir=package_base_dir)
+                run_o(lines, file=file, output=ofiles[0], package_base_dir=package_base_dir, verbose=verbose, show_output=False)
                 run_i(lines, file=file, output=ofiles[0])
             if cut_files:
                 save_s(lines, file_path=os.path.relpath(file, base_path), output_dir=run_out_dirs)
